@@ -50,6 +50,9 @@ FAILEDOPERATION_INQUIRYREFUNDPRICEFAILED = 'FailedOperation.InquiryRefundPriceFa
 # 镜像状态繁忙，请稍后重试。
 FAILEDOPERATION_INVALIDIMAGESTATE = 'FailedOperation.InvalidImageState'
 
+# 不支持操作的applicationRole实例
+FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLE = 'FailedOperation.InvalidInstanceApplicationRole'
+
 # 请求不支持`EMR`的实例`ins-xxxxxxxx`。
 FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'
 
@@ -95,6 +98,9 @@ FAILEDOPERATION_TATAGENTNOTSUPPORT = 'FailedOperation.TatAgentNotSupport'
 # 实例无法退还。
 FAILEDOPERATION_UNRETURNABLE = 'FailedOperation.Unreturnable'
 
+# 给定实例所在可用区不相同，请给定相同可用区的实例。
+FAILEDOPERATION_ZONEINCONSISTENT = 'FailedOperation.ZoneInconsistent'
+
 # 镜像配额超过了限制。
 IMAGEQUOTALIMITEXCEEDED = 'ImageQuotaLimitExceeded'
 
@@ -506,6 +512,9 @@ INVALIDPARAMETERVALUE_PREHEATNOTSUPPORTEDINSTANCETYPE = 'InvalidParameterValue.P
 # 该可用区目前不支持预热功能
 INVALIDPARAMETERVALUE_PREHEATNOTSUPPORTEDZONE = 'InvalidParameterValue.PreheatNotSupportedZone'
 
+# 预热地域不可用，请检查预热地域是否正确。
+INVALIDPARAMETERVALUE_PREHEATUNAVAILABLEZONES = 'InvalidParameterValue.PreheatUnavailableZones'
+
 #  无效参数值。参数值取值范围不合法。
 INVALIDPARAMETERVALUE_RANGE = 'InvalidParameterValue.Range'
 
@@ -704,6 +713,9 @@ RESOURCEINUSE_HPCCLUSTER = 'ResourceInUse.HpcCluster'
 # 该可用区已售罄
 RESOURCEINSUFFICIENT_AVAILABILITYZONESOLDOUT = 'ResourceInsufficient.AvailabilityZoneSoldOut'
 
+# 网段资源不足。
+RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
+
 # 指定的云盘规格已售罄
 RESOURCEINSUFFICIENT_CLOUDDISKSOLDOUT = 'ResourceInsufficient.CloudDiskSoldOut'
 
